@@ -106,10 +106,10 @@ class LoginRequest(DSRequest):
 
         key = 'LoginRequest.send_bot_message'
         settings.LOCKS.acquire(key)
-        if not isinstance(_user, User) and isinstance(_user, int):
+        if isinstance(_user, int):
             _user = User.objects.get(id=_user)
 
-        if not isinstance(_bot, User) and isinstance(_bot, int):
+        if isinstance(_bot, int):
             _bot = User.objects.get(id=_bot)
 
         props = TurnBitOn(0, 0) if compulsory_reading else TurnBitOff(0, 0)
@@ -122,10 +122,13 @@ class LoginRequest(DSRequest):
         def send():
             channel = f'tetatet_{chat_user_user.common_id}'
 
+            guid=uuid.uuid4()
+            # print(f'guid: {guid}')
+
             _message = dict(
                 channel=channel,
                 date=DateToStr(timezone.now(), '%d.%m.%Y, %H:%M:%S', 3),
-                guid=uuid.uuid4(),
+                guid=guid,
                 host=settings.WS_HOST,
                 message=f'<pre>{message}</pre>',
                 message_state_delivered_id=Messages_state.message_state_delivered().id,
