@@ -24,6 +24,6 @@ class Command(BaseCommand):
 
                     if id:
                         cursor.execute(f'alter sequence {seq_name} restart with {id};')
-                        logger.info(f'seq: {table_name}, id: {id}')
+                        print(f'seq: {table_name}, id: {id}')
                 except Exception as e:
-                    logger.error(e)
+                    print(e)
