@@ -75,6 +75,66 @@ class BaseRefQuerySet(AuditQuerySet):
         res = super().create(**kwargs)
         return res
 
+class BaseRefHierarcyQuerySet(BaseRefQuerySet):
+
+    def filter(self, *args, **kwargs):
+        # if self.alive_only:
+        #     setAttr(kwargs, 'deleted_at__isnull', True)
+
+        key = [key for key in kwargs.keys() if key == 'full_name']
+        if len(key) == 0:
+            return super().filter(*args, **kwargs)
+        else:
+            full_name = kwargs.get('full_name')
+            if full_name is not None:
+                res = self.get_full_name_id(None, full_name[1:])
+                delAttr(kwargs, 'full_name')
+                setAttr(kwargs, 'pk', res.pk)
+            else:
+                setAttr(kwargs, 'pk', 0)
+            return super().filter(*args, **kwargs)
+
+    def get_full_name_id(self, parent_id, name):
+        end = False
+        if name.find('/') != -1:
+            _name = name[:name.find('/')]
+        else:
+            end = True
+            _name = name
+
+        if parent_id:
+            res = super().get(parent_id=parent_id, name=_name)
+        else:
+            res = super().get(parent__isnull=True, name=_name)
+
+        if end:
+            return res
+        else:
+            return self.get_full_name_id(res.id, name[name.find('/') + 1:])
+
+    def get(self, *args, **kwargs):
+        key = [key for key in kwargs.keys() if key == 'full_name']
+        if len(key) == 0:
+            res = super().get(*args, **kwargs)
+        else:
+            full_name = kwargs.get('full_name')
+            if full_name is None:
+                full_name = ''
+            res = self.get_full_name_id(None, full_name[1:])
+
+        return res
+
+    def update(self, **kwargs):
+        if kwargs.get('code') is None and kwargs.get('name') is not None:
+            setAttr(kwargs, 'code', AuditModel.translit(kwargs.get('name')))
+        res = super().update(**kwargs)
+        return res
+
+    def create(self, **kwargs):
+        if kwargs.get('code') is None and kwargs.get('name') is not None:
+            setAttr(kwargs, 'code', AuditModel.translit(kwargs.get('name')))
+        res = super().create(**kwargs)
+        return res
 
 class BaseRefManager(AuditManager):
     def get_queryset(self):
@@ -82,6 +142,12 @@ class BaseRefManager(AuditManager):
             return BaseRefQuerySet(model=self.model, alive_only=self.alive_only).filter(deleted_at=None)
         return BaseRefQuerySet(model=self.model, alive_only=False)
 
+class BaseRefHierarcyManager(AuditManager):
+    def get_queryset(self):
+        if self.alive_only:
+            return BaseRefHierarcyQuerySet(model=self.model, alive_only=self.alive_only).filter(deleted_at=None)
+        return BaseRefHierarcyQuerySet(model=self.model, alive_only=False)
+
 
 class StatusBaseRefManager(BaseRefManager):
     def createFromRequest(self, request):
@@ -201,6 +267,9 @@ class BaseRefHierarcy(Hierarcy):
     name = NameField()
     description = DescriptionField()
 
+    def __str__(self):
+        return f'code: {self.code}, name: {self.name}, description: {self.description}'
+
     def save(self, *args, **kwargs):
         if self.code is None:
             self.code = AuditModel.translit(self.name)
